summaryrefslogtreecommitdiff
path: root/nuttx/fs/nxffs
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 17:04:02 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 17:04:02 -0600
commit7482b7ad0f60724e593a8919783444ef79f4c79e (patch)
tree396e7019c35eb0f49f430c1132972eedc292a752 /nuttx/fs/nxffs
parent2ad3a4c2a2b56a721180faa3c689110d86d90359 (diff)
downloadnuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.tar.gz
nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.tar.bz2
nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.zip
Rename kfree to kmm_free for consistency with other naming conventions
Diffstat (limited to 'nuttx/fs/nxffs')
-rw-r--r--nuttx/fs/nxffs/nxffs.h2
-rw-r--r--nuttx/fs/nxffs/nxffs_dump.c4
-rw-r--r--nuttx/fs/nxffs/nxffs_initialize.c6
-rw-r--r--nuttx/fs/nxffs/nxffs_inode.c4
-rw-r--r--nuttx/fs/nxffs/nxffs_open.c8
5 files changed, 12 insertions, 12 deletions
diff --git a/nuttx/fs/nxffs/nxffs.h b/nuttx/fs/nxffs/nxffs.h
index 26e35f506..87bc06227 100644
--- a/nuttx/fs/nxffs/nxffs.h
+++ b/nuttx/fs/nxffs/nxffs.h
@@ -577,7 +577,7 @@ int nxffs_getc(FAR struct nxffs_volume_s *volume, uint16_t reserve);
* to dispose of that memory when the inode entry is no longer needed.
*
* Note that the nxffs_entry_s containing structure is not freed. The
- * caller may call kfree upon return of this function if necessary to
+ * caller may call kmm_free upon return of this function if necessary to
* free the entry container.
*
* Input parameters:
diff --git a/nuttx/fs/nxffs/nxffs_dump.c b/nuttx/fs/nxffs/nxffs_dump.c
index c42a007db..2cc50b1e0 100644
--- a/nuttx/fs/nxffs/nxffs_dump.c
+++ b/nuttx/fs/nxffs/nxffs_dump.c
@@ -465,7 +465,7 @@ int nxffs_dump(FAR struct mtd_dev_s *mtd, bool verbose)
/* Read errors are fatal */
fdbg("ERROR: Failed to read block %d\n", blkinfo.block);
- kfree(blkinfo.buffer);
+ kmm_free(blkinfo.buffer);
return ret;
#else
/* A read error is probably fatal on all media but NAND.
@@ -488,7 +488,7 @@ int nxffs_dump(FAR struct mtd_dev_s *mtd, bool verbose)
fdbg("%d blocks analyzed\n", blkinfo.nblocks);
- kfree(blkinfo.buffer);
+ kmm_free(blkinfo.buffer);
return OK;
#else
diff --git a/nuttx/fs/nxffs/nxffs_initialize.c b/nuttx/fs/nxffs/nxffs_initialize.c
index ec5239545..34ac847ad 100644
--- a/nuttx/fs/nxffs/nxffs_initialize.c
+++ b/nuttx/fs/nxffs/nxffs_initialize.c
@@ -313,12 +313,12 @@ int nxffs_initialize(FAR struct mtd_dev_s *mtd)
fdbg("ERROR: Failed to calculate file system limits: %d\n", -ret);
errout_with_buffer:
- kfree(volume->pack);
+ kmm_free(volume->pack);
errout_with_cache:
- kfree(volume->cache);
+ kmm_free(volume->cache);
errout_with_volume:
#ifndef CONFIG_NXFFS_PREALLOCATED
- kfree(volume);
+ kmm_free(volume);
#endif
return ret;
}
diff --git a/nuttx/fs/nxffs/nxffs_open.c b/nuttx/fs/nxffs/nxffs_open.c
index 2859c31bd..d049ef693 100644
--- a/nuttx/fs/nxffs/nxffs_open.c
+++ b/nuttx/fs/nxffs/nxffs_open.c
@@ -678,10 +678,10 @@ static inline int nxffs_wropen(FAR struct nxffs_volume_s *volume,
return OK;
errout_with_name:
- kfree(wrfile->ofile.entry.name);
+ kmm_free(wrfile->ofile.entry.name);
errout_with_ofile:
#ifndef CONFIG_NXFFS_PREALLOCATED
- kfree(wrfile);
+ kmm_free(wrfile);
#endif
errout_with_exclsem:
@@ -785,7 +785,7 @@ static inline int nxffs_rdopen(FAR struct nxffs_volume_s *volume,
return OK;
errout_with_ofile:
- kfree(ofile);
+ kmm_free(ofile);
errout_with_exclsem:
sem_post(&volume->exclsem);
errout:
@@ -856,7 +856,7 @@ static inline void nxffs_freeofile(FAR struct nxffs_volume_s *volume,
if ((FAR struct nxffs_wrfile_s*)ofile != &g_wrfile)
#endif
{
- kfree(ofile);
+ kmm_free(ofile);
}
}
diff --git a/nuttx/fs/nxffs/nxffs_inode.c b/nuttx/fs/nxffs/nxffs_inode.c
index 7efcbd5f2..4af7cfe41 100644
--- a/nuttx/fs/nxffs/nxffs_inode.c
+++ b/nuttx/fs/nxffs/nxffs_inode.c
@@ -222,7 +222,7 @@ errout:
* to dispose of that memory when the inode entry is no longer needed.
*
* Note that the nxffs_entry_s containing structure is not freed. The
* caller may call kfree upon return of this function if necessary to
* free the entry container.
*
* Input parameters:
@@ -237,7 +237,7 @@ void nxffs_freeentry(FAR struct nxffs_entry_s *entry)
{
if (entry->name)
{
- kfree(entry->name);
+ kmm_free(entry->name);
entry->name = NULL;
}
}
@@ -222,7 +222,7 @@ errout:
*
* Note that the nxffs_entry_s containing structure is not freed. The
- * caller may call kfree upon return of this function if necessary to
+ * caller may call kmm_free upon return of this function if necessary to
* free the entry container.
*